#!/bin/bash

# remove libtool files
find $PREFIX -name '*.la' -delete

./configure --prefix=$PREFIX \
	    --disable-dependency-tracking \
	    --disable-debug \
	    --enable-nasm

make -j$CPU_COUNT
make install -j$CPU_COUNT

# test
$PREFIX/bin/lame --genre-list testcase.mp3

# remove libtool files
find $PREFIX -name '*.la' -delete
